data {
    int N;
    int M;
    array[N, M] int<lower = 1, upper = 2> X;
}
parameters {
    array[M] real mu;
    real<lower = 0.0> psy;
    array[N] real F;
}
transformed parameters {
    array[N, M] real p;
    real sdF;
    real mnF;
    real sumF;
    real ssF;
    array[N] real cF;
    sumF = 0.0;
    ssF = 0.0;
    for (i in 1:N) {
        sumF += F[i];
        ssF += pow(F[i], 2);
    }
    mnF = sumF / N;
    sdF = pow((ssF - N * pow(mnF, 2)) / (N - 1), 0.5);
    for (i in 1:N) {
        cF[i] = (F[i] - mnF) / sdF;
    }

    for (i in 1:N)
        for (j in 1:M){
            p[i][j] = normal_cdf((mu[j] + cF[i]) / psy | 0.0, 1.0);
        }
    
}
model {
    psy ~ exponential(0.1);
    mu ~ normal(0.0, 10.0);
    F ~ normal(0.0, 1.0);
    for (i in 1:N) {
        for (j in 1:M) {
            (X[i][j] - 1) ~ bernoulli(p[i][j]);
        }
    }
}
